==> qmmp-0.6.4.tar.bz2: qmmp-0.6.4/src/plugins/General/covermanager/translations/covermanager_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>CoverManager</name>
    <message>
        <location filename="../covermanager.cpp" line="35"/>
        <source>Show Cover</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../covermanager.cpp" line="36"/>
        <source>Ctrl+M</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CoverManagerFactory</name>
    <message>
        <location filename="../covermanagerfactory.cpp" line="29"/>
        <source>Cover Manager Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../covermanagerfactory.cpp" line="49"/>
        <source>About Cover Manager Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../covermanagerfactory.cpp" line="50"/>
        <source>Qmmp Cover Manager Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../covermanagerfactory.cpp" line="51"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CoverWidget</name>
    <message>
        <location filename="../coverwidget.cpp" line="37"/>
        <source>&amp;Save As...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="37"/>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="38"/>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="40"/>
        <source>Actual Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="41"/>
        <source>128x128</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="42"/>
        <source>256x256</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="43"/>
        <source>512x512</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="44"/>
        <source>1024x1024</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="47"/>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="47"/>
        <source>Alt+F4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="90"/>
        <source>Save Cover As</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="92"/>
        <source>Images</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp-0.10.10.tar.bz2: qmmp-0.10.10/src/plugins/General/covermanager/translations/covermanager_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>CoverManager</name>
    <message>
        <location filename="../covermanager.cpp" line="35"/>
        <source>Show Cover</source>
        <translation>Pokaż okładkę</translation>
    </message>
    <message>
        <location filename="../covermanager.cpp" line="36"/>
        <source>Ctrl+M</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CoverManagerFactory</name>
    <message>
        <location filename="../covermanagerfactory.cpp" line="31"/>
        <source>Cover Manager Plugin</source>
        <translation>Wtyczka zarządzania okładkami</translation>
    </message>
    <message>
        <location filename="../covermanagerfactory.cpp" line="51"/>
        <source>About Cover Manager Plugin</source>
        <translation>O wtyczce Menedżer okładek</translation>
    </message>
    <message>
        <location filename="../covermanagerfactory.cpp" line="52"/>
        <source>Qmmp Cover Manager Plugin</source>
        <translation>Wtyczka Menedżer Okładek dla Qmmp</translation>
    </message>
    <message>
        <location filename="../covermanagerfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Napisana przez: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>CoverWidget</name>
    <message>
        <location filename="../coverwidget.cpp" line="37"/>
        <source>&amp;Save As...</source>
        <translation>Zapi&amp;sz jako...</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="37"/>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="38"/>
        <source>Size</source>
        <translation>Rozmiar</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="40"/>
        <source>Actual Size</source>
        <translation>Aktualny rozmiar</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="41"/>
        <source>128x128</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="42"/>
        <source>256x256</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="43"/>
        <source>512x512</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="44"/>
        <source>1024x1024</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="47"/>
        <source>&amp;Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="47"/>
        <source>Alt+F4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="90"/>
        <source>Save Cover As</source>
        <translation>Zapisz okładkę jako</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="92"/>
        <source>Images</source>
        <translation>Obrazki</translation>
    </message>
</context>
</TS>
